==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleTableInterface_shell.h <==
#ifndef QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H
#define QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleTableInterface_shell : public QAccessibleTableInterface, public QtJambiShellInterface
{
public:
    QAccessibleTableInterface_shell();
    ~QAccessibleTableInterface_shell() override;

    QAccessibleInterface* caption() const override;
    QAccessibleInterface* cellAt(int row0, int column1) const override;
    int columnCount() const override;
    QString columnDescription(int column0) const override;
    bool isColumnSelected(int column0) const override;
    bool isRowSelected(int row0) const override;
    void modelChange(QAccessibleTableModelChangeEvent* event0) override;
    int rowCount() const override;
    QString rowDescription(int row0) const override;
    bool selectColumn(int column0) override;
    bool selectRow(int row0) override;
    int selectedCellCount() const override;
    QList<QAccessibleInterface*> selectedCells() const override;
    int selectedColumnCount() const override;
    QList<int> selectedColumns() const override;
    int selectedRowCount() const override;
    QList<int> selectedRows() const override;
    QAccessibleInterface* summary() const override;
    bool unselectColumn(int column0) override;
    bool unselectRow(int row0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleTableInterface_access : public QAccessibleTableInterface
{
    jobject __qt_caption(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_cellAt_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1) const;
    jint __qt_columnCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_columnDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jboolean __qt_isColumnSelected_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jboolean __qt_isRowSelected_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_modelChange_QAccessibleTableModelChangeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jint __qt_rowCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_rowDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    jboolean __qt_selectColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    jboolean __qt_selectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_selectedCellCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedCells(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_selectedColumnCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedColumns(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_selectedRowCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedRows(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_summary(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_unselectColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    jboolean __qt_unselectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
};

#endif // QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleTableInterface_shell.h <==
#ifndef QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H
#define QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessible.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtJambi/RegistryAPI>


class QAccessibleTableInterface_shell : public QAccessibleTableInterface, public QtJambiShellInterface
{
public:
    QAccessibleTableInterface_shell();
    ~QAccessibleTableInterface_shell() override;

    QAccessibleInterface* caption() const override;
    QAccessibleInterface* cellAt(int row0, int column1) const override;
    int columnCount() const override;
    QString columnDescription(int column0) const override;
    bool isColumnSelected(int column0) const override;
    bool isRowSelected(int row0) const override;
    void modelChange(QAccessibleTableModelChangeEvent* event0) override;
    int rowCount() const override;
    QString rowDescription(int row0) const override;
    bool selectColumn(int column0) override;
    bool selectRow(int row0) override;
    int selectedCellCount() const override;
    QList<QAccessibleInterface*> selectedCells() const override;
    int selectedColumnCount() const override;
    QList<int> selectedColumns() const override;
    int selectedRowCount() const override;
    QList<int> selectedRows() const override;
    QAccessibleInterface* summary() const override;
    bool unselectColumn(int column0) override;
    bool unselectRow(int row0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleTableInterface_access : public QAccessibleTableInterface
{
    jobject __qt_caption_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_cellAt_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1) const;
    jint __qt_columnCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_columnDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jboolean __qt_isColumnSelected_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0) const;
    jboolean __qt_isRowSelected_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    void __qt_modelChange_QAccessibleTableModelChangeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jint __qt_rowCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_rowDescription_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0) const;
    jboolean __qt_selectColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    jboolean __qt_selectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
    jint __qt_selectedCellCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedCells_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_selectedColumnCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedColumns_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_selectedRowCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_selectedRows_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_summary_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_unselectColumn_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0);
    jboolean __qt_unselectRow_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0);
};

#endif // QACCESSIBLETABLEINTERFACE_IMPL_SHELL_H
